@@ -26,7 +26,7 @@ Converting a file from the SubRip format to the MicroDVD format::
 
     project = aeidon.Project()
     project.open_main("/path/to/file.srt", "utf_8")
-    project.set_framerate(aeidon.framerates.FPS_24)
+    project.set_framerate(aeidon.framerates.FPS_23_976)
     project.save_main(aeidon.files.new(aeidon.formats.MICRODVD,
                                        "/path/to/file.sub",
                                        "utf_8"))
@@ -89,7 +89,7 @@ accessing the subtitles directly (via :attr:`aeidon.Project.subtitles`).
 import os
 import re
 
-__version__ = "0.17.1"
+__version__ = "0.19.1"
 
 debug = (bool(os.environ.get("AEIDON_DEBUG", "")) or
          bool(os.environ.get("GAUPOL_DEBUG", "")))
